@@ -2,17 +2,9 @@ package Padre::Task::Perl6;
 
 use strict;
 use warnings;
-use feature 'say';
 use base 'Padre::Task';
 
-use Carp;
-use IPC::Run3;
-use Storable;
-use File::Basename;
-use File::Spec;
-use Cwd;
- 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 our $thread_running = 0;
 
 # This is run in the main thread before being handed
@@ -87,12 +79,16 @@ sub finish {
             }
         }
 		$doc->{tokens} = $self->{tokens};
-        $doc->{issues} = [];
-    } elsif($self->{issues}) {
-        # pass errors/warnings to document...
+    } else {
 		$doc->{tokens} = [];
+	}
+	
+	if($self->{issues}) {
+        # pass errors/warnings to document...
         $doc->{issues} = $self->{issues};
-    }
+    } else {
+		$doc->{issues} = [];
+	}
 	
 	$doc->check_syntax_in_background(force => 1);
 	$doc->get_outline(force => 1);
@@ -106,41 +102,97 @@ sub finish {
 # Task thread subroutine
 sub run {
     my $self = shift;
-    my $text = $self->{text};
-    delete $self->{text};
 
+	# temporary file for the process STDIN
+	require File::Temp;
+	my $tmp_in = File::Temp->new( SUFFIX => '_p6_in.txt' );
+	binmode $tmp_in, ':utf8';
+	print $tmp_in $self->{text};
+	delete $self->{text};
+	close $tmp_in or warn "cannot close $tmp_in\n";
+
+	# temporary file for the process STDOUT
+	my $tmp_out = File::Temp->new( SUFFIX => '_p6_out.txt' );
+	close $tmp_out or warn "cannot close $tmp_out\n";
+	
+	# temporary file for the process STDERR
+	my $tmp_err = File::Temp->new( SUFFIX => '_p6_err.txt' );
+	close $tmp_err or warn "cannot close $tmp_out\n";
+	
     # construct the command
-    my @cmd = ( Padre->perl_interpreter,
-        Cwd::realpath(File::Spec->join(File::Basename::dirname(__FILE__),'p6tokens.pl')));
+	require Cwd;
+	require File::Basename;
+	require File::Spec;
+	my $cmd = Padre->perl_interpreter . " " .
+		Cwd::realpath(File::Spec->join(File::Basename::dirname(__FILE__),'p6tokens.pl')) .
+		" $tmp_in $tmp_out $tmp_err";
+	
+	# all this is needed to prevent win32 platforms from:
+	# 1. popping out a command line on each run...
+	# 2. STD.pm uses Storable 
+	# 3. Padre TaskManager does not like tasks that do Storable operations...
+	my $is_win32 = ($^O =~ /MSWin/);
+	if($is_win32) {
+		use Win32;
+		use Win32::Process;
 
-    my ($out, $err) = ('',undef);
-    run3(\@cmd, \$text, \$out, \$err, { 
-          'binmode_stdin' => ':utf8', 
-          'binmode_stdout' => 1, 
-    });
+		sub print_error {
+		   print Win32::FormatMessage(Win32::GetLastError());
+		}
+
+		my $p_obj;
+		Win32::Process::Create($p_obj, Padre->perl_interpreter, $cmd, 0, DETACHED_PROCESS, '.') 
+			or warn &print_error;
+		$p_obj->Wait(INFINITE);
+	} else {
+		`$cmd`;
+	}
+		
+	my ($out, $err);
+	{
+		local $/ = undef;   #enable localized slurp mode
+
+		# slurp the process output...
+		open CHLD_OUT, $tmp_out	or warn "Could not open $tmp_out";
+		binmode CHLD_OUT;
+		$out = <CHLD_OUT>;
+		close CHLD_OUT or warn "Could not close $tmp_out\n";
+		
+		open CHLD_ERR, $tmp_err or warn "Cannot open $tmp_err\n";
+		binmode CHLD_ERR, ':utf8';
+		$err = <CHLD_ERR>;
+		close CHLD_ERR or warn "Could not close $tmp_err\n";
+	}
+	
     if($err) {
         # remove ANSI color escape sequences...
         $err =~ s/\033\[\d+(?:;\d+(?:;\d+)?)?m//g;
-        say qq{STD.pm warning/error:\n$err};
+        print qq{STD.pm warning/error:\n$err\n};
         my @messages = split /\n/, $err;
-        my ($lineno,$severity);
-        my $issues = [];
+        my ($lineno, $severity);
+		my $issues = [];
         for my $msg (@messages) {
-            if($msg =~ /error\s.+?line (\d+):$/i) {
-                #an error
-                ($lineno,$severity) = ($1, 'E');
-            } elsif($msg =~ /line (\d+):$/i) {
-                #a warning
-                ($lineno,$severity) = ($1, 'W');
-            }
+			if($msg =~ /^\#\#\#\#\# PARSE FAILED \#\#\#\#\#/) {
+				# the following lines are errors until we see the warnings section
+				$severity = 'E';
+			} elsif($msg =~ /^Potential difficulties/) {
+				# all rest are warnings...
+				$severity = 'W';
+			} elsif($msg =~ /line (\d+):$/i) {
+                #record the line number
+                $lineno = $1;
+            } 
             if($lineno) {
                 push @{$issues}, { line => $lineno, msg => $msg, severity => $severity, };
             }
         }
         $self->{issues} = $issues;
-    } else {
+    } 
+	
+	if($out) {
 		eval {
-        	$self->{tokens} = Storable::thaw($out);
+			require Storable;
+         	$self->{tokens} = Storable::thaw($out);
 		};
 		if ($@) {
 			warn "Exception: $@";
